/* YOODA : Yet another Object Oriented Database
   Copyright (C) 1994  Eric Abecassis

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with this library; if not, write to the Free
Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */


/*****************************************************************************
******************************************************************************
**                                                                            
**        Y     Y   OOOO    OOOO   DDDDD     AA
**         Y   Y   O    O  O    O  D    D   A  A
**          Y Y    O    O  O    O  D    D  A    A 
**           Y     O    O  O    O  D    D  AAAAAA
**           Y     O    O  O    O  D    D  A    A
**           Y      OOOO    OOOO   DDDDD   A    A
**
******************************************************************************
******************************************************************************/
/*****************************************************************************
*
*  MODULE :             Simple functions for yooda
*  SCOPE :              Simple functions for yooda
*  FILE :               yoofunc.hxx
*  AUTHORS :            E. Abecassis
*  CREATION DATE :      August 1, 1993
*  COPYRIGHTS :        (C) E. Abecassis, 1993
*  HISTORY :
*
******************************************************************************/

#ifdef __GNUG__
#pragma interface
#endif
#ifndef __yoofunc_HXX
#define __yoofunc_HXX

/* IMPORTS *******************************************************************/

#ifndef __stdio_H
#define __stdio_H
#include <stdio.h>
#endif

#ifndef __errno_H
#define __errno_H
#include <errno.h>
#endif

#ifndef __config_H
#include "config.h"
#endif

#ifndef __class_HXX
#include "class.hxx"
#endif

/*****************************************************************************/


#define SYSCALLI(x) { int res; if ((res = x)==-1) {\
  printf("%s:%d => %d : ",__FILE__,__LINE__,errno);perror("=>"); exit(1);}}

#define SYSCALLP(x) if ((x)==NULL) {\
  printf("%s:%d : ",__FILE__,__LINE__);perror(""); exit(1) ;}

#define SYSCALLPMESS(x, y) if ((x)==NULL) {\
  printf("%s:%d : ",__FILE__,__LINE__);perror(y); exit(1) ;}

#define SYSCALLIMESS(x, y) if ((x)==-1) {\
  printf("%s:%d : ",__FILE__,__LINE__);perror(y); exit(1) ;}


#ifdef TRACE
#define DBG(x) x
#else
#define DBG(x)
#endif

void yoo_exit(int) ;
void yoo_debug(char*) ;
void yoo_debug(char*, int) ;
void yoo_error(int, char*) ;
void yoo_repert() ;
void yoo_env(const char* db, int verbose) ;
caddr_t yoo_mmap(caddr_t addr,size_t len,int prot,int flags,int fd,off_t off);

extern "C" {
void yoo_config() ;
}
void yoo_refreshInit() ;
int yoo_abort() ;
int yoo_commit() ;
int yoo_upgrade() ;
int yoo_checkpoint() ;
int yoo_connect(const char* bd=NULL,const char* server=NULL,int delta=0,int verbose=0) ;
int yoo_disconnect() ;
void yoo_deltavue() ;
void yoo_directvue() ;
int Terminate() ;
void yoo_serverDown(SvcSocket*) ;
void yoo_callbackDown(SvcSocket*) ;
PageHdlMem* yoo_getpage(void* addr) ;

inline int yoo_slotSize (int s) 
{
  return (s-1)/SLOT_SIZE + 1 ;
}


inline int yoo_pageSize (int s) 
{
  return (s-1)/PAGE_SIZE + 1 ;
}


inline unsigned long yoo_alignSup(unsigned long val, int base) {
  return (val-1)/base*base+base ;
}


inline unsigned long yoo_alignInf(unsigned long val, int base) {
  return val/base*base ;
}




#endif

